@@ -60,6 +60,7 @@ struct
       driveId : string;
       includeCorpusRemovals : bool;
       includeItemsFromAllDrives : bool;
+      includeLabels : string;
       includePermissionsForView : string;
       includeRemoved : bool;
       includeTeamDriveItems : bool;
@@ -83,6 +84,7 @@ struct
       driveId = "";
       includeCorpusRemovals = false;
       includeItemsFromAllDrives = false;
+      includeLabels = "";
       includePermissionsForView = "";
       includeRemoved = true;
       includeTeamDriveItems = false;
@@ -108,6 +110,7 @@ struct
       param (fun p -> p.driveId) (fun x -> x) "driveId";
       param (fun p -> p.includeCorpusRemovals) string_of_bool "includeCorpusRemovals";
       param (fun p -> p.includeItemsFromAllDrives) string_of_bool "includeItemsFromAllDrives";
+      param (fun p -> p.includeLabels) (fun x -> x) "includeLabels";
       param (fun p -> p.includePermissionsForView) (fun x -> x) "includePermissionsForView";
       param (fun p -> p.includeRemoved) string_of_bool "includeRemoved";
       param (fun p -> p.includeTeamDriveItems) string_of_bool "includeTeamDriveItems";
@@ -126,6 +129,7 @@ struct
         ?(driveId = default.driveId)
         ?(includeCorpusRemovals = default.includeCorpusRemovals)
         ?(includeItemsFromAllDrives = default.includeItemsFromAllDrives)
+        ?(includeLabels = default.includeLabels)
         ?(includePermissionsForView = default.includePermissionsForView)
         ?(includeRemoved = default.includeRemoved)
         ?(includeTeamDriveItems = default.includeTeamDriveItems)
@@ -147,6 +151,7 @@ struct
         driveId;
         includeCorpusRemovals;
         includeItemsFromAllDrives;
+        includeLabels;
         includePermissionsForView;
         includeRemoved;
         includeTeamDriveItems;
@@ -196,6 +201,7 @@ struct
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
         ?driveId
+        ?includeLabels
         ?includePermissionsForView
         ?teamDriveId
         ~pageToken
@@ -203,9 +209,10 @@ struct
     let full_url = GapiUtils.add_path_to_url ["changes"] base_url in
     let params = ChangesParameters.merge_parameters
       ?standard_parameters:std_params ?driveId ~includeCorpusRemovals
-      ~includeItemsFromAllDrives ?includePermissionsForView ~includeRemoved
-      ~includeTeamDriveItems ~pageSize ~pageToken ~restrictToMyDrive ~spaces
-      ~supportsAllDrives ~supportsTeamDrives ?teamDriveId () in
+      ~includeItemsFromAllDrives ?includeLabels ?includePermissionsForView
+      ~includeRemoved ~includeTeamDriveItems ~pageSize ~pageToken
+      ~restrictToMyDrive ~spaces ~supportsAllDrives ~supportsTeamDrives
+      ?teamDriveId () in
     let query_parameters = GapiOption.map ChangesParameters.to_key_value_list
       params in
     GapiService.get ?query_parameters ?custom_headers full_url
@@ -225,6 +232,7 @@ struct
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
         ?driveId
+        ?includeLabels
         ?includePermissionsForView
         ?teamDriveId
         ~pageToken
@@ -233,9 +241,10 @@ struct
     let full_url = GapiUtils.add_path_to_url ["changes"; "watch"] base_url in
     let params = ChangesParameters.merge_parameters
       ?standard_parameters:std_params ?driveId ~includeCorpusRemovals
-      ~includeItemsFromAllDrives ?includePermissionsForView ~includeRemoved
-      ~includeTeamDriveItems ~pageSize ~pageToken ~restrictToMyDrive ~spaces
-      ~supportsAllDrives ~supportsTeamDrives ?teamDriveId () in
+      ~includeItemsFromAllDrives ?includeLabels ?includePermissionsForView
+      ~includeRemoved ~includeTeamDriveItems ~pageSize ~pageToken
+      ~restrictToMyDrive ~spaces ~supportsAllDrives ~supportsTeamDrives
+      ?teamDriveId () in
     let query_parameters = GapiOption.map ChangesParameters.to_key_value_list
       params in
     GapiService.post ?query_parameters ?custom_headers
@@ -447,6 +456,7 @@ struct
       userIp : string;
       key : string;
       (* drives-specific query parameters *)
+      allowItemDeletion : bool;
       pageSize : int;
       pageToken : string;
       q : string;
@@ -462,6 +472,7 @@ struct
       quotaUser = "";
       userIp = "";
       key = "";
+      allowItemDeletion = false;
       pageSize = 10;
       pageToken = "";
       q = "";
@@ -479,6 +490,7 @@ struct
       param (fun p -> p.quotaUser) (fun x -> x) "quotaUser";
       param (fun p -> p.userIp) (fun x -> x) "userIp";
       param (fun p -> p.key) (fun x -> x) "key";
+      param (fun p -> p.allowItemDeletion) string_of_bool "allowItemDeletion";
       param (fun p -> p.pageSize) string_of_int "pageSize";
       param (fun p -> p.pageToken) (fun x -> x) "pageToken";
       param (fun p -> p.q) (fun x -> x) "q";
@@ -489,6 +501,7 @@ struct
     
     let merge_parameters
         ?(standard_parameters = GapiService.StandardParameters.default)
+        ?(allowItemDeletion = default.allowItemDeletion)
         ?(pageSize = default.pageSize)
         ?(pageToken = default.pageToken)
         ?(q = default.q)
@@ -502,6 +515,7 @@ struct
         quotaUser = standard_parameters.GapiService.StandardParameters.quotaUser;
         userIp = standard_parameters.GapiService.StandardParameters.userIp;
         key = standard_parameters.GapiService.StandardParameters.key;
+        allowItemDeletion;
         pageSize;
         pageToken;
         q;
@@ -533,12 +547,15 @@ struct
         ?(base_url = "https://www.googleapis.com/drive/v3/")
         ?std_params
         ?custom_headers
+        ?(allowItemDeletion = false)
+        ?(useDomainAdminAccess = false)
         ~driveId
         session =
     let full_url = GapiUtils.add_path_to_url ["drives";
       ((fun x -> x) driveId)] base_url in
     let params = DrivesParameters.merge_parameters
-      ?standard_parameters:std_params () in
+      ?standard_parameters:std_params ~allowItemDeletion
+      ~useDomainAdminAccess () in
     let query_parameters = GapiOption.map DrivesParameters.to_key_value_list
       params in
     GapiService.delete ?query_parameters ?custom_headers full_url
@@ -672,9 +689,11 @@ struct
       enforceSingleParent : bool;
       ignoreDefaultVisibility : bool;
       includeItemsFromAllDrives : bool;
+      includeLabels : string;
       includePermissionsForView : string;
       includeTeamDriveItems : bool;
       keepRevisionForever : bool;
+      maxResults : int;
       mimeType : string;
       ocrLanguage : string;
       orderBy : string;
@@ -708,9 +727,11 @@ struct
       enforceSingleParent = false;
       ignoreDefaultVisibility = false;
       includeItemsFromAllDrives = false;
+      includeLabels = "";
       includePermissionsForView = "";
       includeTeamDriveItems = false;
       keepRevisionForever = false;
+      maxResults = 100;
       mimeType = "";
       ocrLanguage = "";
       orderBy = "";
@@ -746,9 +767,11 @@ struct
       param (fun p -> p.enforceSingleParent) string_of_bool "enforceSingleParent";
       param (fun p -> p.ignoreDefaultVisibility) string_of_bool "ignoreDefaultVisibility";
       param (fun p -> p.includeItemsFromAllDrives) string_of_bool "includeItemsFromAllDrives";
+      param (fun p -> p.includeLabels) (fun x -> x) "includeLabels";
       param (fun p -> p.includePermissionsForView) (fun x -> x) "includePermissionsForView";
       param (fun p -> p.includeTeamDriveItems) string_of_bool "includeTeamDriveItems";
       param (fun p -> p.keepRevisionForever) string_of_bool "keepRevisionForever";
+      param (fun p -> p.maxResults) string_of_int "maxResults";
       param (fun p -> p.mimeType) (fun x -> x) "mimeType";
       param (fun p -> p.ocrLanguage) (fun x -> x) "ocrLanguage";
       param (fun p -> p.orderBy) (fun x -> x) "orderBy";
@@ -777,9 +800,11 @@ struct
         ?(enforceSingleParent = default.enforceSingleParent)
         ?(ignoreDefaultVisibility = default.ignoreDefaultVisibility)
         ?(includeItemsFromAllDrives = default.includeItemsFromAllDrives)
+        ?(includeLabels = default.includeLabels)
         ?(includePermissionsForView = default.includePermissionsForView)
         ?(includeTeamDriveItems = default.includeTeamDriveItems)
         ?(keepRevisionForever = default.keepRevisionForever)
+        ?(maxResults = default.maxResults)
         ?(mimeType = default.mimeType)
         ?(ocrLanguage = default.ocrLanguage)
         ?(orderBy = default.orderBy)
@@ -811,9 +836,11 @@ struct
         enforceSingleParent;
         ignoreDefaultVisibility;
         includeItemsFromAllDrives;
+        includeLabels;
         includePermissionsForView;
         includeTeamDriveItems;
         keepRevisionForever;
+        maxResults;
         mimeType;
         ocrLanguage;
         orderBy;
@@ -843,6 +870,7 @@ struct
         ?(keepRevisionForever = false)
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
+        ?includeLabels
         ?includePermissionsForView
         ?ocrLanguage
         ~fileId
@@ -852,7 +880,7 @@ struct
       "copy"] base_url in
     let params = FilesParameters.merge_parameters
       ?standard_parameters:std_params ~enforceSingleParent
-      ~ignoreDefaultVisibility ?includePermissionsForView
+      ~ignoreDefaultVisibility ?includeLabels ?includePermissionsForView
       ~keepRevisionForever ?ocrLanguage ~supportsAllDrives
       ~supportsTeamDrives () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
@@ -872,22 +900,26 @@ struct
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
         ?(useContentAsIndexableText = false)
+        ?includeLabels
         ?includePermissionsForView
         ?ocrLanguage
         file
         session =
     let base_path = ["files"] in
-    let media_path = [""; "resumable"; "upload"; "drive"; "v3"; "files"] in
+    let media_path = [""; "upload"; "drive"; "v3"; "files"] in
     let path_to_add = if GapiOption.is_some media_source then media_path
       else base_path in
     let full_url = GapiUtils.add_path_to_url path_to_add base_url in
     let params = FilesParameters.merge_parameters
       ?standard_parameters:std_params ~enforceSingleParent
-      ~ignoreDefaultVisibility ?includePermissionsForView
+      ~ignoreDefaultVisibility ?includeLabels ?includePermissionsForView
       ~keepRevisionForever ?ocrLanguage ~supportsAllDrives
       ~supportsTeamDrives ~useContentAsIndexableText () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
       params in
+    let query_parameters = GapiOption.map (fun xs ->
+      if GapiOption.is_some media_source then ("uploadType", "resumable")
+      :: xs else xs) query_parameters in
     GapiService.post ?query_parameters ?media_source ?custom_headers
       ~data_to_post:(GapiJson.render_json File.to_data_model) ~data:file
       full_url (GapiJson.parse_json_response File.of_data_model) session 
@@ -968,13 +1000,14 @@ struct
         ?(acknowledgeAbuse = false)
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
+        ?includeLabels
         ?includePermissionsForView
         ~fileId
         session =
     let full_url = GapiUtils.add_path_to_url ["files"; ((fun x -> x) fileId)]
       base_url in
     let params = FilesParameters.merge_parameters
-      ?standard_parameters:std_params ~acknowledgeAbuse
+      ?standard_parameters:std_params ~acknowledgeAbuse ?includeLabels
       ?includePermissionsForView ~supportsAllDrives ~supportsTeamDrives () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
       params in
@@ -994,6 +1027,7 @@ struct
         ?corpora
         ?corpus
         ?driveId
+        ?includeLabels
         ?includePermissionsForView
         ?orderBy
         ?pageToken
@@ -1003,7 +1037,7 @@ struct
     let full_url = GapiUtils.add_path_to_url ["files"] base_url in
     let params = FilesParameters.merge_parameters
       ?standard_parameters:std_params ?corpora ?corpus ?driveId
-      ~includeItemsFromAllDrives ?includePermissionsForView
+      ~includeItemsFromAllDrives ?includeLabels ?includePermissionsForView
       ~includeTeamDriveItems ?orderBy ~pageSize ?pageToken ?q ~spaces
       ~supportsAllDrives ~supportsTeamDrives ?teamDriveId () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
@@ -1011,6 +1045,42 @@ struct
     GapiService.get ?query_parameters ?custom_headers full_url
       (GapiJson.parse_json_response FileList.of_data_model) session 
     
+  let listLabels
+        ?(base_url = "https://www.googleapis.com/drive/v3/")
+        ?std_params
+        ?custom_headers
+        ?(maxResults = 100)
+        ?pageToken
+        ~fileId
+        session =
+    let full_url = GapiUtils.add_path_to_url ["files"; ((fun x -> x) fileId);
+      "listLabels"] base_url in
+    let params = FilesParameters.merge_parameters
+      ?standard_parameters:std_params ~maxResults ?pageToken () in
+    let query_parameters = GapiOption.map FilesParameters.to_key_value_list
+      params in
+    GapiService.get ?query_parameters ?custom_headers full_url
+      (GapiJson.parse_json_response LabelList.of_data_model) session 
+    
+  let modifyLabels
+        ?(base_url = "https://www.googleapis.com/drive/v3/")
+        ?std_params
+        ?custom_headers
+        ~fileId
+        modifyLabelsRequest
+        session =
+    let full_url = GapiUtils.add_path_to_url ["files"; ((fun x -> x) fileId);
+      "modifyLabels"] base_url in
+    let params = FilesParameters.merge_parameters
+      ?standard_parameters:std_params () in
+    let query_parameters = GapiOption.map FilesParameters.to_key_value_list
+      params in
+    GapiService.post ?query_parameters ?custom_headers
+      ~data_to_post:(GapiJson.render_json ModifyLabelsRequest.to_data_model)
+      ~data:modifyLabelsRequest full_url
+      (GapiJson.parse_json_response ModifyLabelsResponse.of_data_model)
+      session 
+    
   let update
         ?(base_url = "https://www.googleapis.com/drive/v3/")
         ?std_params
@@ -1022,6 +1092,7 @@ struct
         ?(supportsTeamDrives = false)
         ?(useContentAsIndexableText = false)
         ?addParents
+        ?includeLabels
         ?includePermissionsForView
         ?ocrLanguage
         ?removeParents
@@ -1029,18 +1100,21 @@ struct
         file
         session =
     let base_path = ["files"; ((fun x -> x) fileId)] in
-    let media_path = [""; "resumable"; "upload"; "drive"; "v3"; "files";
+    let media_path = [""; "upload"; "drive"; "v3"; "files";
       ((fun x -> x) fileId)] in
     let path_to_add = if GapiOption.is_some media_source then media_path
       else base_path in
     let full_url = GapiUtils.add_path_to_url path_to_add base_url in
     let params = FilesParameters.merge_parameters
       ?standard_parameters:std_params ?addParents ~enforceSingleParent
-      ?includePermissionsForView ~keepRevisionForever ?ocrLanguage
-      ?removeParents ~supportsAllDrives ~supportsTeamDrives
+      ?includeLabels ?includePermissionsForView ~keepRevisionForever
+      ?ocrLanguage ?removeParents ~supportsAllDrives ~supportsTeamDrives
       ~useContentAsIndexableText () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
       params in
+    let query_parameters = GapiOption.map (fun xs ->
+      if GapiOption.is_some media_source then ("uploadType", "resumable")
+      :: xs else xs) query_parameters in
     GapiService.patch ?query_parameters ?media_source ?custom_headers
       ~data_to_post:(GapiJson.render_json File.to_data_model) ~data:file
       full_url (GapiJson.parse_json_response File.of_data_model) session 
@@ -1053,6 +1127,7 @@ struct
         ?(acknowledgeAbuse = false)
         ?(supportsAllDrives = false)
         ?(supportsTeamDrives = false)
+        ?includeLabels
         ?includePermissionsForView
         ~fileId
         channel
@@ -1060,7 +1135,7 @@ struct
     let full_url = GapiUtils.add_path_to_url ["files"; ((fun x -> x) fileId);
       "watch"] base_url in
     let params = FilesParameters.merge_parameters
-      ?standard_parameters:std_params ~acknowledgeAbuse
+      ?standard_parameters:std_params ~acknowledgeAbuse ?includeLabels
       ?includePermissionsForView ~supportsAllDrives ~supportsTeamDrives () in
     let query_parameters = GapiOption.map FilesParameters.to_key_value_list
       params in
